#ifndef MID314_CONST_H
#define MID314_CONST_H

#include "midsraytypes.h"


#define COLORSPACE_YUY2  1  //(primary mode)
#define COLORSPACE_RGB32 2  //
#define COLORSPACE_RGB24 3  //(primary mode)
#define COLORSPACE_UYVY  4 

/** MID314_AUDIO_INPUT sets the audio input channel,  
 *  @param MID314_AUDIO_LINE line in
 *  @param MID314_AUDIO_MIC microphone
 */
typedef enum
{
	MID314_AUDIO_LINE,
	MID314_AUDIO_MIC
}  MID314_AUDIO_INPUT;


/** Video input source.  Note: Changing input may stop MPEG Video Stream
 * @param MID314_SOURCE_COMPOSITE_0 Composite channel 0
 * @param MID314_SOURCE_SVIDEO_0 S-Video Channel 0
 * @param MID314_SOURCE_NUM maximum number of inputs
 */
typedef enum
{
	MID314_SOURCE_COMPOSITE_0 = 0,
    MID314_SOURCE_COMPOSITE_1 = 1,
    MID314_SOURCE_COMPOSITE_2 = 2,
    MID314_SOURCE_COMPOSITE_3 = 3,
    MID314_SOURCE_SVIDEO_0 = 4,
	MID314_SOURCE_SVIDEO_1 = 5,
	MID314_SOURCE_NUM	   = 6    // maximum number of inputs
} MID314_SOURCE;


// backwards compatibility.  
#define MID314_API                 MIDSRAY_API
#define MID314_SUCCESS             MIDSRAY_SUCCESS
#define MID314_ERR_NONE            MIDSRAY_ERR_NONE
#define MID314_ERR_UNSPECIFIED     MIDSRAY_ERR_UNSPECIFIED
#define MID314_ERR_CAPTURING       MIDSRAY_ERR_CAPTURING       
#define MID314_ERR_NOTCAPTURING    MIDSRAY_ERR_NOTCAPTURING
#define MID314_ERR_RUNNING         MIDSRAY_ERR_RUNNING
#define MID314_ERR_SNAPSHOT        MIDSRAY_ERR_SNAPSHOT
#define MID314_ERR_INVALIDFILE     MIDSRAY_ERR_INVALIDFILE
#define MID314_ERR_DIRECTX         MIDSRAY_ERR_DIRECTX
#define MID314_ERR_NODEVICE		   MIDSRAY_ERR_NODEVICE
#define MID314_ERR_NOTINITIALIZED  MIDSRAY_ERR_NOTINITIALIZED
#define MID314_ERR_INVALIDMODE     MIDSRAY_ERR_INVALIDMODE

/** sequence modes(advanced use only) */
typedef enum 
{
    MID314_SEQMODE_DEFAULT = 0,
    MID314_SEQMODE_I       = 1,
    MID314_SEQMODE_IP      = 2,
    MID314_SEQMODE_IPB     = 3
} MID314_SEQMODE;

/** operating modes, Normal, Motion JPEG capture with no rendering(display)
*/
typedef enum
{
    MID314_OPMODE_NORMAL=MIDSRAY_OPMODE_NORMAL,
    MID314_OPMODE_MJPEG_CAPTURE = MIDSRAY_OPMODE_MJPEG_CAPTURE
} MID314_OPMODE;

/** video systems.  PAL or NTSC
 */
typedef enum
{
	MID314_VIDSYS_PAL=MIDSRAY_VIDSYS_PAL,
	MID314_VIDSYS_NTSC=MIDSRAY_VIDSYS_NTSC
} MID314_VIDSYS;



/** VIDEO levels */
#define MID314_LEVEL_CONTRAST		MIDSRAY_LEVEL_CONTRAST
#define	MID314_LEVEL_BRIGHTNESS	    MIDSRAY_LEVEL_BRIGHTNESS
#define MID314_LEVEL_SATURATION	    MIDSRAY_LEVEL_SATURATION
#define MID314_LEVEL_HUE			MIDSRAY_LEVEL_HUE


// image file save bitmask types 
 
#define	MID314_FILE_JPEG		MIDSRAY_FILE_JPEG
#define	MID314_FILE_BMP			MIDSRAY_FILE_BMP
#define	MID314_FILE_PPM			MIDSRAY_FILE_PPM


/** Encoding type (MPEG, etc)
 */
typedef enum
{
	MID314_ENCODE_MPEG1 = MIDSRAY_ENCODE_MPEG1,
	MID314_ENCODE_MPEG2 = MIDSRAY_ENCODE_MPEG2,
	MID314_ENCODE_MPEG4 = MIDSRAY_ENCODE_MPEG4,
	MID314_ENCODE_MOTIONJPEG = MIDSRAY_ENCODE_MOTIONJPEG,
    MID314_ENCODE_RAWVID = MIDSRAY_ENCODE_NONE,
	MID314_ENCODE_MPEG4DIVX = MIDSRAY_ENCODE_MPEG4DIVX,

} MID314_ENCODING;

/** recording mode for saved MPEG streams
 *  @param MIDSRAY_REC_MUX multiplexed(video+audio) mpeg stream
 *  @param MIDSRAY_REC_VES video elementary stream( video only)
 *  @param MIDSRAY_REC_AUDIOWAVE audio only.  recorded as a WAVE file.
 *  @param MIDSRAY_REC_AES encoded audio only (AES mp2 encoding)
 */
typedef enum
{
	MID314_REC_MUX = MIDSRAY_REC_MUX,        // default: multiplexed(video+audio) mpeg stream
	MID314_REC_PES = MIDSRAY_REC_PES,        // video elementary stream( video only)
    MID314_REC_VES = MIDSRAY_REC_VES,        // currently unsupported.  testing only
    MID314_REC_SPLIT = MIDSRAY_REC_SPLIT4    // split record,  AVI raw video, WAV raw audio
} MID314_REC;

typedef enum
{	
	MID314_ASPECT_NONE = 0,	// no aspect ratio change
	MID314_ASPECT_CONST = 1	// maintain aspect ratio
} MID314_ASPECT_MODE;

typedef enum
{
	MID314_RES_D1 = MIDSRAY_RES_D1,
	MID314_RES_SIF = MIDSRAY_RES_SIF,  // NTSC only
    MID314_RES_CIF = MIDSRAY_RES_CIF ,  // PAL only
    MID314_RES_VGA = MIDSRAY_RES_VGA,
    MID314_RES_QCIF = MIDSRAY_RES_QCIF
}  MID314_RES;



#endif
