#ifndef MIDSRAY_CONST_H
#define MIDSRAY_CONST_H

#ifdef ISDLLBUILD
    #define MIDSRAY_API extern "C" __declspec(dllexport)
#else
#ifdef __cplusplus
    #define MIDSRAY_API extern "C" __declspec(dllimport)
#else
    #define MIDSRAY_API __declspec(dllimport)
#endif
#endif

#define MAX_OVERLAYS 6

// error constants 
#define MIDSRAY_SUCCESS             0
#define MIDSRAY_ERR_NONE            0
#define MIDSRAY_ERR_UNSPECIFIED     -1
#define MIDSRAY_ERR_CAPTURING       -2   // already capturing/recording
#define MIDSRAY_ERR_NOTCAPTURING    -3   // not capturing/recording
#define MIDSRAY_ERR_RUNNING         -4   // attempt to set configuration while graph running
#define MIDSRAY_ERR_SNAPSHOT        -5   // currently displaying snapshot
#define MIDSRAY_ERR_INVALIDFILE     -6   // invalid file
#define MIDSRAY_ERR_DIRECTX         -7   // directX error( other specific directX errors are possible)
#define MIDSRAY_ERR_NODEVICE		-8   // device not present
#define MIDSRAY_ERR_NOTINITIALIZED  -9	 // initialization function failed or not called
#define MIDSRAY_ERR_INVALIDMODE    -10  // invalid mode(eg.  record in MJPEG CAPTURE mode)

/** sequence modes(advanced use only) */
typedef enum 
{
    MIDSRAY_SEQMODE_IFRAMESONLY,  
    MIDSRAY_SEQMODE_DEFAULT
} MIDSRAY_SEQMODE;

/** operating modes, Normal, Motion JPEG capture with no rendering(display)
*/
typedef enum
{
    MIDSRAY_OPMODE_NORMAL=0,
    MIDSRAY_OPMODE_MJPEG_CAPTURE
} MIDSRAY_OPMODE;

/** video systems.  PAL or NTSC
 */
typedef enum
{
	MIDSRAY_VIDSYS_PAL=1,
	MIDSRAY_VIDSYS_NTSC=2
} MIDSRAY_VIDSYS;


/** Video input source.  Note: Changing input may stop MPEG Video Stream
 * @param MIDSRAY_SOURCE_COMPOSITE_0 Composite channel 0
 * @param MIDSRAY_SOURCE_SVIDEO_0 S-Video Channel 0
 * @param MIDSRAY_SOURCE_NUM maximum number of inputs
 */
typedef enum
{
	MIDSRAY_SOURCE_COMPOSITE_0 = 0,
    MIDSRAY_SOURCE_COMPOSITE_1 = 1,
    MIDSRAY_SOURCE_COMPOSITE_2 = 2,
    MIDSRAY_SOURCE_COMPOSITE_3 = 3,
    MIDSRAY_SOURCE_SVIDEO_0 = 4,
	MIDSRAY_SOURCE_SVIDEO_1 = 5,
	MIDSRAY_SOURCE_NUM	   = 6    // maximum number of inputs
} MIDSRAY_SOURCE;


/** VIDEO levels */
#define MIDSRAY_LEVEL_CONTRAST		1
#define	MIDSRAY_LEVEL_BRIGHTNESS	    2
#define MIDSRAY_LEVEL_SATURATION	    4
#define MIDSRAY_LEVEL_HUE			8


// image file save bitmask types 
 
#define	MIDSRAY_FILE_JPEG		1
#define	MIDSRAY_FILE_BMP			2
#define	MIDSRAY_FILE_PPM			4


/** Encoding type (MPEG, etc)
 */
typedef enum
{
	MIDSRAY_ENCODE_MPEG1 = 0,
	MIDSRAY_ENCODE_MPEG2 = 1,
	MIDSRAY_ENCODE_MPEG4 = 2,  // MP4S  microsoft MPG4.  not for VES
	MIDSRAY_ENCODE_MOTIONJPEG = 4,
    MIDSRAY_ENCODE_NONE = 3,
	MIDSRAY_ENCODE_MPEG4DIVX = 9,  //DIVX MPG4.  for VES
} MIDSRAY_ENCODING;

/** General Status information
 * @param bIsRecording true if currently recording
 * @param bIsPlaying true if video playing(for debug)      
 * @param iFilesize current recorded file size
 * @param szFilepath current filepath being recorded
 */
typedef struct 
{ 
    ULONG       iFilesize;              // current recorded size(megs)
    TCHAR       szFilepath[MAX_PATH];   // current filepath
    BOOL        bIsRecording;           // true if currently recording
    BOOL        bIsPlaying;             // true if video streaming(preview)
    BOOL        bRecordAudio;
    BOOL        bRecordVideo;
    TCHAR       szEncode[MAX_PATH];
    int         iEncode;
} MIDSRAYSTATUS; 

/** overlay text structure
 *  @param text pointer to text
 */
#define MAX_OVLTEXT 96  // maximum TOTAL number of characters in the overlay.
// eg.  User may have one Overlay text with 96 characters
//      or 2 overlays( idx=0, idx=1) with 48 characters each
typedef struct {
	char text[MAX_OVLTEXT];	 // MAX_PATH
	char reserved[32];
} overlay_text_t;


/** MIDSRAY_AUDIO_INPUT sets the audio input channel,  
 *  @param MIDSRAY_AUDIO_LINE line in
 *  @param MIDSRAY_AUDIO_MIC microphone
 */
typedef enum
{
	MIDSRAY_AUDIO_LINE,
	MIDSRAY_AUDIO_MIC
}  MIDSRAY_AUDIO_INPUT;


/** aspect ratio settings for MPEG decoding on host computer.  Depending on Decoder, may not have an effect.
 * @param MIDSRAY_ASPECT_NONE no aspect ratio change on MPEG decoding(stretch to window)
 * @param MIDSRAY_ASPECT_CONST maintain aspect ratio as video settings
 */
typedef enum
{	
	MIDSRAY_ASPECT_NONE = 0,	// no aspect ratio change
	MIDSRAY_ASPECT_CONST = 1	// maintain aspect ratio
} MIDSRAY_ASPECT_MODE;

/** recording mode for saved MPEG streams
 *  @param MIDSRAY_REC_MUX multiplexed(video+audio) mpeg stream
 *  @param MIDSRAY_REC_VES video elementary stream( video only)
 *  @param MIDSRAY_REC_AUDIOWAVE audio only.  recorded as a WAVE file.
 *  @param MIDSRAY_REC_AES encoded audio only (AES mp2 encoding)
 */
typedef enum
{
	MIDSRAY_REC_MUX = 0,        // default: multiplexed(video+audio) mpeg stream
	MIDSRAY_REC_PES = 1,        // video elementary stream( video only)
    MIDSRAY_REC_VES = 2,        // currently unsupported.  testing only
    MIDSRAY_REC_SPLIT1 = 3,     // VES/AES(BETA)
    MIDSRAY_REC_SPLIT2 = 4,     // VES/WAV(BETA)
    MIDSRAY_REC_SPLIT3 = 5,     // PES/AES(BETA)
    MIDSRAY_REC_SPLIT4 = 6,     // PEV/WAV(BETA)
    MIDSRAY_REC_AES = 7,        // Audio elementary stream only(no video, beta)
    MIDSRAY_REC_AUDIOWAVE = 8  //  audio wave( beta)
} MIDSRAY_REC;


/** motion detection coordinates in pixels*/
typedef struct
{
    int CoordsX;
    int CoordsY;
} MIDSRAY_PointCorrds_t;

/** motion detection regions.  Region 4 is NOT available at this time.  Only 3 regions are available.
 *  eg ULPoint[3], BRPoint[3] values are ignored
 *  @param ULPoint[n] Upper left point coordinate of region n+1.
 *  @param BRPoint[n] bottom right point coordinate of region n+1.
 *  @param u32SADThresholdValues[n] Sum of absolute differences for region n+1. Recommended range 20-150(depends on sensitivity).  
 *  @param u32MVThresholdValues[n] Motion Vector threshold of region n+1. Recommended range 50-1500(depends on sensitivity).
 *  @param u32SensitivityValues[n] Sensitivity. 0-100.  100 will produce too many events in general.  Recommend 0-80 range
 *  To turn off a region, use threshold values of 0x7fff and set ULPoint[n] = {0,0} and BRPoint[n]={0,0}.
 */
typedef struct
{
    MIDSRAY_PointCorrds_t ULPoint[ 4 ];
    MIDSRAY_PointCorrds_t BRPoint[ 4 ];
    unsigned short u32SADThresholdValues[ 4 ];
    unsigned short u32MVThresholdValues[ 4 ];
    unsigned short u32SensitivityValues[ 4 ];
} MIDSRAY_MDConfig_t;

/** Resolutions
 *  D1  -- 720x 480 NTSC, 720x576 PAL
 *  SIF -- 352 x 240  // NTSC only
 *  CIF -- 352 x 288  // PAL only
 *  VGA -- 640x480
 *  4SIF -- 704x480 // NTSC only
 *  4CIF -- 704x576 // PAL only
 *  QCIF -- 176x144 // 
 */
typedef enum
{
	MIDSRAY_RES_D1 = 0,
	MIDSRAY_RES_SIF,  // NTSC only (except 314NC)
    MIDSRAY_RES_CIF,  // PAL only  (except 314NC)
    MIDSRAY_RES_VGA,
    MIDSRAY_RES_QCIF,
    MIDSRAY_RES_QVGA, // 314 NC only
    MIDSRAY_RES_4SIF, // 314 NC only
    MIDSRAY_RES_4CIF, // 314 NC only
    MIDSRAY_RES_D5,  // 314 NC only
    MIDSRAY_RES_2SIF, // 314 NC only
    MIDSRAY_RES_QQVGA, // 314 NC only
    MIDSRAY_RES_SQCIF, //// 314 NC only
    MIDSRAY_RES_D1N, //// 314 NC only
    MIDSRAY_RES_D1P, //// 314 NC only
}  MIDSRAY_RES;

#endif
